@@ -53,26 +53,37 @@ class PrometheusMetric(object):
 
 
 class PrometheusAPIClient(object):
-    def __init__(self, host):
+    def __init__(self, host, session=None, root_path=""):
         self._host = host
-        self._session = requests.Session()
+        if not self._host.endswith('/'):
+            self._host += '/'
+        if session is None:
+            self._session = requests.Session()
+        else:
+            self._session = session
         self._session.verify = False
+        self._root_path = root_path
+        if root_path != "" and not self._root_path.endswith('/'):
+            self._root_path += '/'
 
     def set_ca_cert(self, ca_cert):
         self._session.verify = ca_cert
 
     def set_client_cert(self, client_cert, client_key):
-        self._session.cert = client_cert
-        self._session.key = client_key
+        self._session.cert = (client_cert, client_key)
 
     def set_basic_auth(self, auth_user, auth_password):
         self._session.auth = (auth_user, auth_password)
 
+    def _get_url(self, endpoint):
+        scheme = 'https' if self._session.verify else 'http'
+        return f"{scheme}://{self._host}{self._root_path}api/v1/{endpoint}"
+
     def _get(self, endpoint, params=None):
-        url = (f"{'https' if self._session.verify else 'http'}://"
-               f"{self._host}/api/v1/{endpoint}")
+        url = self._get_url(endpoint)
         resp = self._session.get(url, params=params,
-                                 headers={'Accept': 'application/json'})
+                                 headers={'Accept': 'application/json',
+                                          'Accept-Encoding': 'identity'})
         if resp.status_code != requests.codes.ok:
             raise PrometheusAPIClientError(resp)
         decoded = resp.json()
@@ -82,8 +93,7 @@ class PrometheusAPIClient(object):
         return decoded
 
     def _post(self, endpoint, params=None):
-        url = (f"{'https' if self._session.verify else 'http'}://"
-               f"{self._host}/api/v1/{endpoint}")
+        url = self._get_url(endpoint)
         resp = self._session.post(url, params=params,
                                   headers={'Accept': 'application/json'})
         if resp.status_code != requests.codes.ok:
